@@ -9,41 +9,41 @@
 #' @details
 #' Consider partially linear panel regression (PLR) model of form
 #'
-#' \eqn{ Y_{it} = \theta_0 D_{it} + g_0(x_{it}) + \alpha_i + U_{it} (1)}
+#' \eqn{ Y_{it} = \theta_0 D_{it} + g_0(x_{it}) + \alpha_i + U_{it}}
 #'
-#' \eqn{ D_{it} = m_0(x_{it}) + \gamma_i + V_{it}  (2)}
+#' \eqn{ D_{it} = m_0(x_{it}) + \gamma_i + V_{it}}
 #'
 #' where (1) is the outcome equation and (2) is the treatment equation.
 #'
 #' @usage NULL
 #'
 #' @examples
-#'
 #' # An illustrative example using a regression tree (`rpart`)
 #' library(mlr3)
 #' library(rpart)
 #'
-#' set.seed(1234)
-#'
 #' # Generate simulated dataset
-#' data = make_plpr_data(n_obs = 100, t_per = 5, dim_x = 10, theta = 0.5, rho=0.8)
+#' data = make_plpr_data(n_obs = 500, t_per = 10, dim_x = 30, theta = 0.5, rho=0.8)
 #'
-#' x_cols  = paste0("X", 1:10)
+#' x_cols  = paste0("X", 1:30)
 #'
-#' # Set up DML data environment
 #' obj_xtdml_data = xtdml_data_from_data_frame(data,
 #'                 x_cols = x_cols,  y_col = "y", d_cols = "d",
-#'                 cluster_cols = "id", approach = "fd-exact")
+#'                 panel_id = "id",
+#'                 time_id = "time",
+#'                 cluster_cols = "id",
+#'                 approach = "fd-exact",
+#'                 transformX = "no")
 #'
 #' # Set up DML estimation environment
-#'  learner = lrn("regr.rpart")
-#'  ml_l = learner$clone()
-#'  ml_m = learner$clone()
+#'   learner = lrn("regr.rpart")
+#'   ml_l = learner$clone()
+#'   ml_m = learner$clone()
 #'
-#'  obj_xtdml = xtdml_plr$new(obj_xtdml_data,
+#'   obj_xtdml = xtdml_plr$new(obj_xtdml_data,
 #'                            ml_l = ml_l, ml_m = ml_m,
 #'                            score = "orth-PO", n_folds = 3)
-#'  obj_xtdml$fit()
+#'   obj_xtdml$fit()
 #'
 #' @export
 xtdml_plr <- R6Class("xtdml_plr",
@@ -242,13 +242,15 @@ xtdml_plr <- R6Class("xtdml_plr",
     #' class [ParamSet][paradox::ParamSet].
     #'
     #' @param tune_settings (named `list()`) \cr
-    #' A named `list()` with arguments passed to the hyperparameter-tuning with
-    #' [mlr3tuning](https://mlr3tuning.mlr-org.com/) to set up
-    #' [TuningInstance][mlr3tuning::TuningInstanceSingleCrit] objects.
-    #' `tune_settings` has entries
-    #' * `terminator` ([Terminator][bbotk::Terminator]) \cr
-    #' A [Terminator][bbotk::Terminator] object. Specification of `terminator`
-    #' is required to perform tuning.
+    #' A named list of settings that control the hyperparameter tuning
+    #' performed via [mlr3tuning](https://mlr3tuning.mlr-org.com/).
+    #' These settings are used to construct
+    #' [TuningInstanceSingleCrit][mlr3tuning::TuningInstanceSingleCrit] objects.
+    #' The list can contain the following elements:
+    #' * `terminator` (`[bbotk::Terminator]`, required) \cr
+    #'   A [Terminator][bbotk::Terminator] object specifying when the tuning
+    #'   process should stop (e.g., `trm("evals", n_evals = 20)`).
+    #'
     #' * `algorithm` ([Tuner][mlr3tuning::Tuner] or `character(1)`) \cr
     #' A [Tuner][mlr3tuning::Tuner] object (recommended) or key passed to the
     #' respective dictionary to specify the tuning algorithm used in
@@ -256,22 +258,21 @@ xtdml_plr <- R6Class("xtdml_plr",
     #' [tnr()][mlr3tuning::tnr()]. If `algorithm` is not specified by the users,
     #' default is set to `"grid_search"`. If set to `"grid_search"`, then
     #' additional argument `"resolution"` is required.
-    #' * `rsmp_tune` ([Resampling][mlr3::Resampling] or `character(1)`)\cr
-    #' A [Resampling][mlr3::Resampling] object (recommended) or option passed
-    #' to [rsmp()][mlr3::mlr_sugar] to initialize a
-    #' [Resampling][mlr3::Resampling] for parameter tuning in `mlr3`.
-    #' If not specified by the user, default is set to `"cv"`
-    #' (cross-validation).
-    #' * `n_folds_tune` (`integer(1)`, optional) \cr
-    #' If `rsmp_tune = "cv"`, number of folds used for cross-validation.
-    #' If not specified by the user, default is set to `5`.
-    #' * `measure` (`NULL`, named `list()`, optional) \cr
-    #' Named list containing the measures used for parameter tuning. Entries in
-    #' list must either be [Measure][mlr3::Measure] objects or keys to be
-    #' passed to passed to [msr()][mlr3::msr()]. The names of the entries must
-    #' match the learner names (see method `learner_names()`). If set to `NULL`,
-    #' default measures are used, i.e., `"regr.mse"` for continuous outcome
-    #' variables and `"classif.ce"` for binary outcomes.
+    #' * `rsmp_tune` (`[mlr3::Resampling]` or `character(1)`) \cr
+    #'   A resampling strategy used during tuning. Can be given either as a
+    #'   [Resampling][mlr3::Resampling] object or a key passed to
+    #'   [rsmp()][mlr3::rsmp()] (e.g., `"cv"` for cross-validation).
+    #'   The default is 5-fold cross-validation.
+    #' * `n_folds_tune` (`integer(1)`) \cr
+    #'   Number of folds to use when `rsmp_tune = "cv"`. Default is `5`.
+    #' * `measure` (`NULL` or named `list()`) \cr
+    #'   A named list specifying performance measures for each learner.
+    #'   Each element must be either a [Measure][mlr3::Measure] object or
+    #'   a key passed to [msr()][mlr3::msr()].
+    #'   The names of the list elements must match the learner names
+    #'   (see `learner_names()`).
+    #'   If `NULL`, default measures are used: `"regr.mse"` for regression
+    #'   and `"classif.ce"` for classification.
     #' * `resolution` (`character(1)`) \cr The key passed to the respective
     #' dictionary to specify  the tuning algorithm used in
     #' [tnr()][mlr3tuning::tnr()]. `resolution` is passed as an argument to
@@ -281,50 +282,6 @@ xtdml_plr <- R6Class("xtdml_plr",
     #' Indicates whether the tuning should be done fold-specific or globally.
     #' Default is `FALSE`.
     #'
-    #' @examples
-    #' # Tuning example with `rpart`
-    #' library(mlr3)
-    #' library(rpart)
-    #' library(mlr3misc)
-    #' library(mlr3tuning)
-    #'
-    #' set.seed(1234)
-    #'
-    #' # Generate simulated dataset
-    #' data = make_plpr_data(n_obs = 100, t_per = 5, dim_x = 10, theta = 0.5, rho=0.8)
-    #'
-    #' x_cols  = paste0("X", 1:10)
-    #'
-    #' # Set up DML data environment
-    #' obj_xtdml_data = xtdml_data_from_data_frame(data,
-    #'                 x_cols = x_cols,  y_col = "y", d_cols = "d",
-    #'                 cluster_cols = "id", approach = "fd-exact")
-    #'
-    #' # Set up DML estimation environment
-    #'   learner = lrn("regr.rpart")
-    #'   ml_l = learner$clone()
-    #'   ml_m = learner$clone()
-    #'
-    #'   obj_xtdml = xtdml_plr$new(obj_xtdml_data,
-    #'                            ml_l = ml_l, ml_m = ml_m,
-    #'                            score = "orth-PO", n_folds = 3)
-    #' # Set up a list of parameter grids
-    #' param_grid = list("ml_l" = ps(cp = p_dbl(lower = 0.01, upper = 0.02),
-    #'                             maxdepth = p_int(lower = 2, upper = 10)),
-    #'                   "ml_m" = ps(cp = p_dbl(lower = 0.01, upper = 0.02),
-    #'                             maxdepth = p_int(lower = 2, upper = 10)))
-    #'
-    #' tune_settings = list(n_folds_tune = 3,
-    #'                    rsmp_tune = mlr3::rsmp("cv", folds = 3),
-    #'                    terminator = mlr3tuning::trm("evals", n_evals = 5),
-    #'                    algorithm = tnr("grid_search"), resolution = 5)
-    #'
-    #' obj_xtdml$tune(param_set = param_grid, tune_settings = tune_settings)
-    #'
-    #' # Estimate target/causal parameter
-    #' obj_xtdml$fit()
-    #' obj_xtdml$print()
-    #'
     #' @return self
     tune = function(param_set, tune_settings = list(
       n_folds_tune = 5,
@@ -332,8 +289,8 @@ xtdml_plr <- R6Class("xtdml_plr",
       measure = NULL,
       terminator = mlr3tuning::trm("evals", n_evals = 20),
       algorithm = mlr3tuning::tnr("grid_search"),
-      resolution = 5),
-    tune_on_folds = FALSE) {
+      resolution = 10),
+      tune_on_folds = FALSE) {
 
       assert_list(param_set)
       if (self$score == "orth-PO") {
@@ -561,8 +518,8 @@ xtdml_plr <- R6Class("xtdml_plr",
           ##give two options
           if (self$score == "orth-IV") {
           # orthogonal score
-            psi_theta_a = -(d - m_hat) * (d - m_hat)
-            psi_theta_b =  (d - m_hat) * (y - l_hat)
+            psi_theta_a = -(d - m_hat$preds) * (d - m_hat$preds)
+            psi_theta_b =  (d - m_hat$preds) * (y - l_hat$preds)
 
           }
 
